import{s as Wn,n as Bn,o as Un}from"../chunks/scheduler.6062bdaf.js";import{S as Gn,i as jn,g as o,s as i,u as c,A as Kn,h as r,f as t,c as s,j as m,v as f,y as u,k as l,o as n,a as p,w as h,d as g,t as x,x as v}from"../chunks/index.7658fce3.js";import{D as y}from"../chunks/Docstring.5ab7be14.js";import{I as He}from"../chunks/IconCopyLink.d844a6a2.js";function Jn(rn){let $,je,Fe,Ke,O,q,Re,U,St,ge,sn="Configuration classes for ONNX exports",Je,G,an="Exporting a model to ONNX involves specifying:",Ye,j,pn=`<li>The input names.</li> <li>The output names.</li> <li>The dynamic axes. These refer to the input dimensions can be changed dynamically at runtime (e.g. a batch size or sequence length).
All other axes will be treated as static, and hence fixed at runtime.</li> <li>Dummy inputs to trace the model. This is needed in PyTorch to record the computational graph and convert it to ONNX.</li>`,Ze,K,ln=`Since this data depends on the choice of model and task, we represent it in terms of <em>configuration classes</em>. Each configuration class is associated with
a specific model architecture, and follows the naming convention <code>ArchitectureNameOnnxConfig</code>. For instance, the configuration which specifies the ONNX
export of BERT models is <code>BertOnnxConfig</code>.`,Qe,J,mn="Since many architectures share similar properties for their ONNX configuration, 🤗 Optimum adopts a 3-level class hierarchy:",et,Y,un=`<li>Abstract and generic base classes. These handle all the fundamental features, while being agnostic to the modality (text, image, audio, etc).</li> <li>Middle-end classes. These are aware of the modality, but multiple can exist for the same modality depending on the inputs they support.
They specify which input generators should be used for the dummy inputs, but remain model-agnostic.</li> <li>Model-specific classes like the <code>BertOnnxConfig</code> mentioned above. These are the ones actually used to export models.</li>`,tt,w,M,Xe,Z,Dt,xe,dn="Base classes",nt,d,Q,Lt,ve,cn="Base class for ONNX exportable model describing metadata on how to export the model through the ONNX format.",qt,_e,fn="Class attributes:",Mt,ye,hn=`<li>NORMALIZED_CONFIG_CLASS (<code>Type</code>) — A class derived from <a href="/docs/optimum/main/en/utils/normalized_config#optimum.utils.NormalizedConfig">NormalizedConfig</a> specifying how to
normalize the model config.</li> <li>DUMMY_INPUT_GENERATOR_CLASSES (<code>Tuple[Type]</code>) — A tuple of classes derived from
<a href="/docs/optimum/main/en/utils/dummy_input_generators#optimum.utils.DummyInputGenerator">DummyInputGenerator</a> specifying how to create dummy inputs.</li> <li>ATOL_FOR_VALIDATION (<code>Union[float, Dict[str, float]]</code>) — A float or a dictionary mapping task names to float,
where the float values represent the absolute tolerance value to use during model conversion validation.</li> <li>DEFAULT_ONNX_OPSET (<code>int</code>, defaults to 11) — The default ONNX opset to use for the ONNX export.</li> <li>MIN_TORCH_VERSION (<code>packaging.version.Version</code>, defaults to <code>~optimum.exporters.onnx.utils.TORCH_MINIMUM_VERSION</code>) — The
minimum torch version supporting the export of the model to ONNX.</li> <li>MIN_TRANSFORMERS_VERSION (<code>packaging.version.Version</code>, defaults to
<code>~optimum.exporters.onnx.utils.TRANSFORMERS_MINIMUM_VERSION</code> — The minimum transformers version supporting the
export of the model to ONNX. Not always up-to-date or accurate. This is more for internal use.</li> <li>PATCHING_SPECS (<code>Optional[List[PatchingSpec]]</code>, defaults to <code>None</code>) — Specify which operators / modules should be
patched before performing the export, and how. This is useful when some operator is not supported in ONNX for
instance.</li>`,It,I,ee,Vt,be,gn="Dict containing the axis definition of the input tensors to provide to the model.",Ht,V,te,Ft,Ce,xn="Dict containing the axis definition of the output tensors to provide to the model.",Rt,H,ne,Xt,$e,vn="Generates the dummy inputs necessary for tracing the model. If not explicitely specified, default input shapes are used.",ot,b,oe,zt,Oe,_n='Inherits from <a href="/docs/optimum/main/en/exporters/onnx/package_reference/configuration#optimum.exporters.onnx.OnnxConfig">OnnxConfig</a>. A base class to handle the ONNX configuration of decoder-only models.',Wt,F,re,Bt,we,yn="Fills <code>input_or_outputs</code> mapping with past_key_values dynamic axes considering the direction.",rt,C,ie,Ut,Te,bn='Inherits from <a href="/docs/optimum/main/en/exporters/onnx/package_reference/configuration#optimum.exporters.onnx.OnnxConfigWithPast">OnnxConfigWithPast</a>. A base class to handle the ONNX configuration of encoder-decoder models.',Gt,R,se,jt,Ne,Cn="Creates a copy of the current OnnxConfig but with a different <code>ConfigBehavior</code> and <code>use_past</code> value.",it,T,X,ze,ae,Kt,Pe,$n="Middle-end classes",st,N,z,We,pe,Jt,ke,On="Text",at,P,le,Yt,Ee,wn="Handles encoder-based text architectures.",pt,k,me,Zt,Ae,Tn="Handles decoder-based text architectures.",lt,E,ue,Qt,Se,Nn="Handles encoder-decoder-based text architectures.",mt,A,W,Be,de,en,De,Pn="Vision",ut,S,ce,tn,Le,kn="Handles vision architectures.",dt,D,B,Ue,fe,nn,qe,En="Multi-modal",ct,L,he,on,Me,An="Handles multi-modal text and vision architectures.",ft,Ge,ht;return U=new He({}),Z=new He({}),Q=new y({props:{name:"class optimum.exporters.onnx.OnnxConfig",anchor:"optimum.exporters.onnx.OnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfig.config",description:`<strong>config</strong> (<code>transformers.PretrainedConfig</code>) &#x2014;
The model configuration.`,name:"config"},{anchor:"optimum.exporters.onnx.OnnxConfig.task",description:`<strong>task</strong> (<code>str</code>, defaults to <code>&quot;feature-extraction&quot;</code>) &#x2014;
The task the model should be exported for.`,name:"task"},{anchor:"optimum.exporters.onnx.OnnxConfig.int_dtype",description:`<strong>int_dtype</strong> (<code>str</code>, defaults to <code>&quot;int64&quot;</code>) &#x2014;
The data type of integer tensors, could be [&#x201C;int64&#x201D;, &#x201C;int32&#x201D;, &#x201C;int8&#x201D;], default to &#x201C;int64&#x201D;.`,name:"int_dtype"},{anchor:"optimum.exporters.onnx.OnnxConfig.float_dtype",description:`<strong>float_dtype</strong> (<code>str</code>, defaults to <code>&quot;fp32&quot;</code>) &#x2014;
The data type of float tensors, could be [&#x201C;fp32&#x201D;, &#x201C;fp16&#x201D;, &#x201C;bf16&#x201D;], default to &#x201C;fp32&#x201D;.`,name:"float_dtype"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L102"}}),ee=new y({props:{name:"inputs",anchor:"optimum.exporters.onnx.OnnxConfig.inputs",parameters:[],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L230",returnDescription:`
<p>A mapping of each input name to a mapping of axis position to the axes symbolic name.</p>
`,returnType:`
<p><code>Dict[str, Dict[int, str]]</code></p>
`}}),te=new y({props:{name:"outputs",anchor:"optimum.exporters.onnx.OnnxConfig.outputs",parameters:[],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L241",returnDescription:`
<p>A mapping of each output name to a mapping of axis position to the axes symbolic name.</p>
`,returnType:`
<p><code>Dict[str, Dict[int, str]]</code></p>
`}}),ne=new y({props:{name:"generate_dummy_inputs",anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs",parameters:[{name:"framework",val:": str = 'pt'"},{name:"**kwargs",val:""}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.framework",description:`<strong>framework</strong> (<code>str</code>, defaults to <code>&quot;pt&quot;</code>) &#x2014;
The framework for which to create the dummy inputs.`,name:"framework"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.batch_size",description:`<strong>batch_size</strong> (<code>int</code>, defaults to 2) &#x2014;
The batch size to use in the dummy inputs.`,name:"batch_size"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.sequence_length",description:`<strong>sequence_length</strong> (<code>int</code>, defaults to 16) &#x2014;
The sequence length to use in the dummy inputs.`,name:"sequence_length"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.num_choices",description:`<strong>num_choices</strong> (<code>int</code>, defaults to 4) &#x2014;
The number of candidate answers provided for multiple choice task.`,name:"num_choices"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.image_width",description:`<strong>image_width</strong> (<code>int</code>, defaults to 64) &#x2014;
The width to use in the dummy inputs for vision tasks.`,name:"image_width"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.image_height",description:`<strong>image_height</strong> (<code>int</code>, defaults to 64) &#x2014;
The height to use in the dummy inputs for vision tasks.`,name:"image_height"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.num_channels",description:`<strong>num_channels</strong> (<code>int</code>, defaults to 3) &#x2014;
The number of channels to use in the dummpy inputs for vision tasks.`,name:"num_channels"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.feature_size",description:`<strong>feature_size</strong> (<code>int</code>, defaults to 80) &#x2014;
The number of features to use in the dummpy inputs for audio tasks in case it is not raw audio.
This is for example the number of STFT bins or MEL bins.`,name:"feature_size"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.nb_max_frames",description:`<strong>nb_max_frames</strong> (<code>int</code>, defaults to 3000) &#x2014;
The number of frames to use in the dummpy inputs for audio tasks in case the input is not raw audio.`,name:"nb_max_frames"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.audio_sequence_length",description:`<strong>audio_sequence_length</strong> (<code>int</code>, defaults to 16000) &#x2014;
The number of frames to use in the dummpy inputs for audio tasks in case the input is raw audio.`,name:"audio_sequence_length"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L452",returnDescription:`
<p>A dictionary mapping the input names to dummy tensors in the proper framework format.</p>
`,returnType:`
<p><code>Dict</code></p>
`}}),oe=new y({props:{name:"class optimum.exporters.onnx.OnnxConfigWithPast",anchor:"optimum.exporters.onnx.OnnxConfigWithPast",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L553"}}),re=new y({props:{name:"add_past_key_values",anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values",parameters:[{name:"inputs_or_outputs",val:": typing.Dict[str, typing.Dict[int, str]]"},{name:"direction",val:": str"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values.inputs_or_outputs",description:`<strong>inputs_or_outputs</strong> (<code>Dict[str, Dict[int, str]]</code>) &#x2014;
The mapping to fill.`,name:"inputs_or_outputs"},{anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values.direction",description:`<strong>direction</strong> (<code>str</code>) &#x2014;
either &#x201C;inputs&#x201D; or &#x201C;outputs&#x201D;, it specifies whether <code>input_or_outputs</code> is the input mapping or the
output mapping, this is important for axes naming.`,name:"direction"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L683"}}),ie=new y({props:{name:"class optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast",anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"behavior",val:": ConfigBehavior = <ConfigBehavior.MONOLITH: 'monolith'>"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L756"}}),se=new y({props:{name:"with_behavior",anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior",parameters:[{name:"behavior",val:": typing.Union[str, optimum.exporters.onnx.base.ConfigBehavior]"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.behavior",description:`<strong>behavior</strong> (<code>ConfigBehavior</code>) &#x2014;
The behavior to use for the new instance.`,name:"behavior"},{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.use_past",description:`<strong>use_past</strong> (<code>bool</code>, defaults to <code>False</code>) &#x2014;
Whether or not the ONNX config to instantiate is for a model using KV cache.`,name:"use_past"},{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.use_past_in_inputs",description:`<strong>use_past_in_inputs</strong> (<code>bool</code>, defaults to <code>False</code>) &#x2014;
Whether the KV cache is to be passed as an input to the ONNX.`,name:"use_past_in_inputs"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L789",returnType:`
<p><code>OnnxSeq2SeqConfigWithPast</code></p>
`}}),ae=new He({}),pe=new He({}),le=new y({props:{name:"class optimum.exporters.onnx.TextEncoderOnnxConfig",anchor:"optimum.exporters.onnx.TextEncoderOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L52"}}),me=new y({props:{name:"class optimum.exporters.onnx.TextDecoderOnnxConfig",anchor:"optimum.exporters.onnx.TextDecoderOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"no_position_ids",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L60"}}),ue=new y({props:{name:"class optimum.exporters.onnx.TextSeq2SeqOnnxConfig",anchor:"optimum.exporters.onnx.TextSeq2SeqOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"behavior",val:": ConfigBehavior = <ConfigBehavior.MONOLITH: 'monolith'>"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L175"}}),de=new He({}),ce=new y({props:{name:"class optimum.exporters.onnx.config.VisionOnnxConfig",anchor:"optimum.exporters.onnx.config.VisionOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L242"}}),fe=new He({}),he=new y({props:{name:"class optimum.exporters.onnx.config.TextAndVisionOnnxConfig",anchor:"optimum.exporters.onnx.config.TextAndVisionOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L250"}}),{c(){$=o("meta"),je=i(),Fe=o("p"),Ke=i(),O=o("h1"),q=o("a"),Re=o("span"),c(U.$$.fragment),St=i(),ge=o("span"),ge.textContent=sn,Je=i(),G=o("p"),G.textContent=an,Ye=i(),j=o("ol"),j.innerHTML=pn,Ze=i(),K=o("p"),K.innerHTML=ln,Qe=i(),J=o("p"),J.textContent=mn,et=i(),Y=o("ol"),Y.innerHTML=un,tt=i(),w=o("h2"),M=o("a"),Xe=o("span"),c(Z.$$.fragment),Dt=i(),xe=o("span"),xe.textContent=dn,nt=i(),d=o("div"),c(Q.$$.fragment),Lt=i(),ve=o("p"),ve.textContent=cn,qt=i(),_e=o("p"),_e.textContent=fn,Mt=i(),ye=o("ul"),ye.innerHTML=hn,It=i(),I=o("div"),c(ee.$$.fragment),Vt=i(),be=o("p"),be.textContent=gn,Ht=i(),V=o("div"),c(te.$$.fragment),Ft=i(),Ce=o("p"),Ce.textContent=xn,Rt=i(),H=o("div"),c(ne.$$.fragment),Xt=i(),$e=o("p"),$e.textContent=vn,ot=i(),b=o("div"),c(oe.$$.fragment),zt=i(),Oe=o("p"),Oe.innerHTML=_n,Wt=i(),F=o("div"),c(re.$$.fragment),Bt=i(),we=o("p"),we.innerHTML=yn,rt=i(),C=o("div"),c(ie.$$.fragment),Ut=i(),Te=o("p"),Te.innerHTML=bn,Gt=i(),R=o("div"),c(se.$$.fragment),jt=i(),Ne=o("p"),Ne.innerHTML=Cn,it=i(),T=o("h2"),X=o("a"),ze=o("span"),c(ae.$$.fragment),Kt=i(),Pe=o("span"),Pe.textContent=$n,st=i(),N=o("h3"),z=o("a"),We=o("span"),c(pe.$$.fragment),Jt=i(),ke=o("span"),ke.textContent=On,at=i(),P=o("div"),c(le.$$.fragment),Yt=i(),Ee=o("p"),Ee.textContent=wn,pt=i(),k=o("div"),c(me.$$.fragment),Zt=i(),Ae=o("p"),Ae.textContent=Tn,lt=i(),E=o("div"),c(ue.$$.fragment),Qt=i(),Se=o("p"),Se.textContent=Nn,mt=i(),A=o("h3"),W=o("a"),Be=o("span"),c(de.$$.fragment),en=i(),De=o("span"),De.textContent=Pn,ut=i(),S=o("div"),c(ce.$$.fragment),tn=i(),Le=o("p"),Le.textContent=kn,dt=i(),D=o("h3"),B=o("a"),Ue=o("span"),c(fe.$$.fragment),nn=i(),qe=o("span"),qe.textContent=En,ct=i(),L=o("div"),c(he.$$.fragment),on=i(),Me=o("p"),Me.textContent=An,ft=i(),Ge=o("p"),this.h()},l(e){const a=Kn("svelte-1phssyn",document.head);$=r(a,"META",{name:!0,content:!0}),a.forEach(t),je=s(e),Fe=r(e,"P",{}),m(Fe).forEach(t),Ke=s(e),O=r(e,"H1",{class:!0});var gt=m(O);q=r(gt,"A",{id:!0,class:!0,href:!0});var Sn=m(q);Re=r(Sn,"SPAN",{});var Dn=m(Re);f(U.$$.fragment,Dn),Dn.forEach(t),Sn.forEach(t),St=s(gt),ge=r(gt,"SPAN",{"data-svelte-h":!0}),u(ge)!=="svelte-1yfsuiw"&&(ge.textContent=sn),gt.forEach(t),Je=s(e),G=r(e,"P",{"data-svelte-h":!0}),u(G)!=="svelte-dlt5nt"&&(G.textContent=an),Ye=s(e),j=r(e,"OL",{"data-svelte-h":!0}),u(j)!=="svelte-8uy4wn"&&(j.innerHTML=pn),Ze=s(e),K=r(e,"P",{"data-svelte-h":!0}),u(K)!=="svelte-dj35tg"&&(K.innerHTML=ln),Qe=s(e),J=r(e,"P",{"data-svelte-h":!0}),u(J)!=="svelte-1xr1iy9"&&(J.textContent=mn),et=s(e),Y=r(e,"OL",{"data-svelte-h":!0}),u(Y)!=="svelte-172xxrj"&&(Y.innerHTML=un),tt=s(e),w=r(e,"H2",{class:!0});var xt=m(w);M=r(xt,"A",{id:!0,class:!0,href:!0});var Ln=m(M);Xe=r(Ln,"SPAN",{});var qn=m(Xe);f(Z.$$.fragment,qn),qn.forEach(t),Ln.forEach(t),Dt=s(xt),xe=r(xt,"SPAN",{"data-svelte-h":!0}),u(xe)!=="svelte-kuv5qq"&&(xe.textContent=dn),xt.forEach(t),nt=s(e),d=r(e,"DIV",{class:!0});var _=m(d);f(Q.$$.fragment,_),Lt=s(_),ve=r(_,"P",{"data-svelte-h":!0}),u(ve)!=="svelte-1gqzpaz"&&(ve.textContent=cn),qt=s(_),_e=r(_,"P",{"data-svelte-h":!0}),u(_e)!=="svelte-wz8va1"&&(_e.textContent=fn),Mt=s(_),ye=r(_,"UL",{"data-svelte-h":!0}),u(ye)!=="svelte-1043q6c"&&(ye.innerHTML=hn),It=s(_),I=r(_,"DIV",{class:!0});var vt=m(I);f(ee.$$.fragment,vt),Vt=s(vt),be=r(vt,"P",{"data-svelte-h":!0}),u(be)!=="svelte-41mopq"&&(be.textContent=gn),vt.forEach(t),Ht=s(_),V=r(_,"DIV",{class:!0});var _t=m(V);f(te.$$.fragment,_t),Ft=s(_t),Ce=r(_t,"P",{"data-svelte-h":!0}),u(Ce)!=="svelte-ayslnd"&&(Ce.textContent=xn),_t.forEach(t),Rt=s(_),H=r(_,"DIV",{class:!0});var yt=m(H);f(ne.$$.fragment,yt),Xt=s(yt),$e=r(yt,"P",{"data-svelte-h":!0}),u($e)!=="svelte-jhf9pw"&&($e.textContent=vn),yt.forEach(t),_.forEach(t),ot=s(e),b=r(e,"DIV",{class:!0});var Ie=m(b);f(oe.$$.fragment,Ie),zt=s(Ie),Oe=r(Ie,"P",{"data-svelte-h":!0}),u(Oe)!=="svelte-1bekc5k"&&(Oe.innerHTML=_n),Wt=s(Ie),F=r(Ie,"DIV",{class:!0});var bt=m(F);f(re.$$.fragment,bt),Bt=s(bt),we=r(bt,"P",{"data-svelte-h":!0}),u(we)!=="svelte-1vefvm0"&&(we.innerHTML=yn),bt.forEach(t),Ie.forEach(t),rt=s(e),C=r(e,"DIV",{class:!0});var Ve=m(C);f(ie.$$.fragment,Ve),Ut=s(Ve),Te=r(Ve,"P",{"data-svelte-h":!0}),u(Te)!=="svelte-1o424ha"&&(Te.innerHTML=bn),Gt=s(Ve),R=r(Ve,"DIV",{class:!0});var Ct=m(R);f(se.$$.fragment,Ct),jt=s(Ct),Ne=r(Ct,"P",{"data-svelte-h":!0}),u(Ne)!=="svelte-1mrnpw0"&&(Ne.innerHTML=Cn),Ct.forEach(t),Ve.forEach(t),it=s(e),T=r(e,"H2",{class:!0});var $t=m(T);X=r($t,"A",{id:!0,class:!0,href:!0});var Mn=m(X);ze=r(Mn,"SPAN",{});var In=m(ze);f(ae.$$.fragment,In),In.forEach(t),Mn.forEach(t),Kt=s($t),Pe=r($t,"SPAN",{"data-svelte-h":!0}),u(Pe)!=="svelte-tmz6ke"&&(Pe.textContent=$n),$t.forEach(t),st=s(e),N=r(e,"H3",{class:!0});var Ot=m(N);z=r(Ot,"A",{id:!0,class:!0,href:!0});var Vn=m(z);We=r(Vn,"SPAN",{});var Hn=m(We);f(pe.$$.fragment,Hn),Hn.forEach(t),Vn.forEach(t),Jt=s(Ot),ke=r(Ot,"SPAN",{"data-svelte-h":!0}),u(ke)!=="svelte-58799s"&&(ke.textContent=On),Ot.forEach(t),at=s(e),P=r(e,"DIV",{class:!0});var wt=m(P);f(le.$$.fragment,wt),Yt=s(wt),Ee=r(wt,"P",{"data-svelte-h":!0}),u(Ee)!=="svelte-sreje6"&&(Ee.textContent=wn),wt.forEach(t),pt=s(e),k=r(e,"DIV",{class:!0});var Tt=m(k);f(me.$$.fragment,Tt),Zt=s(Tt),Ae=r(Tt,"P",{"data-svelte-h":!0}),u(Ae)!=="svelte-1fe0pgy"&&(Ae.textContent=Tn),Tt.forEach(t),lt=s(e),E=r(e,"DIV",{class:!0});var Nt=m(E);f(ue.$$.fragment,Nt),Qt=s(Nt),Se=r(Nt,"P",{"data-svelte-h":!0}),u(Se)!=="svelte-1yn8wb"&&(Se.textContent=Nn),Nt.forEach(t),mt=s(e),A=r(e,"H3",{class:!0});var Pt=m(A);W=r(Pt,"A",{id:!0,class:!0,href:!0});var Fn=m(W);Be=r(Fn,"SPAN",{});var Rn=m(Be);f(de.$$.fragment,Rn),Rn.forEach(t),Fn.forEach(t),en=s(Pt),De=r(Pt,"SPAN",{"data-svelte-h":!0}),u(De)!=="svelte-3auvp1"&&(De.textContent=Pn),Pt.forEach(t),ut=s(e),S=r(e,"DIV",{class:!0});var kt=m(S);f(ce.$$.fragment,kt),tn=s(kt),Le=r(kt,"P",{"data-svelte-h":!0}),u(Le)!=="svelte-10ord85"&&(Le.textContent=kn),kt.forEach(t),dt=s(e),D=r(e,"H3",{class:!0});var Et=m(D);B=r(Et,"A",{id:!0,class:!0,href:!0});var Xn=m(B);Ue=r(Xn,"SPAN",{});var zn=m(Ue);f(fe.$$.fragment,zn),zn.forEach(t),Xn.forEach(t),nn=s(Et),qe=r(Et,"SPAN",{"data-svelte-h":!0}),u(qe)!=="svelte-1u7csay"&&(qe.textContent=En),Et.forEach(t),ct=s(e),L=r(e,"DIV",{class:!0});var At=m(L);f(he.$$.fragment,At),on=s(At),Me=r(At,"P",{"data-svelte-h":!0}),u(Me)!=="svelte-1fm9mpu"&&(Me.textContent=An),At.forEach(t),ft=s(e),Ge=r(e,"P",{}),m(Ge).forEach(t),this.h()},h(){l($,"name","hf:doc:metadata"),l($,"content",JSON.stringify(Yn)),l(q,"id","configuration-classes-for-onnx-exports"),l(q,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(q,"href","#configuration-classes-for-onnx-exports"),l(O,"class","relative group"),l(M,"id","optimum.exporters.onnx.OnnxConfig"),l(M,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(M,"href","#optimum.exporters.onnx.OnnxConfig"),l(w,"class","relative group"),l(I,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(V,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(H,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(d,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(F,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(b,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(R,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(C,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(X,"id","middleend-classes"),l(X,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(X,"href","#middleend-classes"),l(T,"class","relative group"),l(z,"id","optimum.exporters.onnx.TextEncoderOnnxConfig"),l(z,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(z,"href","#optimum.exporters.onnx.TextEncoderOnnxConfig"),l(N,"class","relative group"),l(P,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(k,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(E,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(W,"id","optimum.exporters.onnx.config.VisionOnnxConfig"),l(W,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(W,"href","#optimum.exporters.onnx.config.VisionOnnxConfig"),l(A,"class","relative group"),l(S,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),l(B,"id","optimum.exporters.onnx.config.TextAndVisionOnnxConfig"),l(B,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),l(B,"href","#optimum.exporters.onnx.config.TextAndVisionOnnxConfig"),l(D,"class","relative group"),l(L,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8")},m(e,a){n(document.head,$),p(e,je,a),p(e,Fe,a),p(e,Ke,a),p(e,O,a),n(O,q),n(q,Re),h(U,Re,null),n(O,St),n(O,ge),p(e,Je,a),p(e,G,a),p(e,Ye,a),p(e,j,a),p(e,Ze,a),p(e,K,a),p(e,Qe,a),p(e,J,a),p(e,et,a),p(e,Y,a),p(e,tt,a),p(e,w,a),n(w,M),n(M,Xe),h(Z,Xe,null),n(w,Dt),n(w,xe),p(e,nt,a),p(e,d,a),h(Q,d,null),n(d,Lt),n(d,ve),n(d,qt),n(d,_e),n(d,Mt),n(d,ye),n(d,It),n(d,I),h(ee,I,null),n(I,Vt),n(I,be),n(d,Ht),n(d,V),h(te,V,null),n(V,Ft),n(V,Ce),n(d,Rt),n(d,H),h(ne,H,null),n(H,Xt),n(H,$e),p(e,ot,a),p(e,b,a),h(oe,b,null),n(b,zt),n(b,Oe),n(b,Wt),n(b,F),h(re,F,null),n(F,Bt),n(F,we),p(e,rt,a),p(e,C,a),h(ie,C,null),n(C,Ut),n(C,Te),n(C,Gt),n(C,R),h(se,R,null),n(R,jt),n(R,Ne),p(e,it,a),p(e,T,a),n(T,X),n(X,ze),h(ae,ze,null),n(T,Kt),n(T,Pe),p(e,st,a),p(e,N,a),n(N,z),n(z,We),h(pe,We,null),n(N,Jt),n(N,ke),p(e,at,a),p(e,P,a),h(le,P,null),n(P,Yt),n(P,Ee),p(e,pt,a),p(e,k,a),h(me,k,null),n(k,Zt),n(k,Ae),p(e,lt,a),p(e,E,a),h(ue,E,null),n(E,Qt),n(E,Se),p(e,mt,a),p(e,A,a),n(A,W),n(W,Be),h(de,Be,null),n(A,en),n(A,De),p(e,ut,a),p(e,S,a),h(ce,S,null),n(S,tn),n(S,Le),p(e,dt,a),p(e,D,a),n(D,B),n(B,Ue),h(fe,Ue,null),n(D,nn),n(D,qe),p(e,ct,a),p(e,L,a),h(he,L,null),n(L,on),n(L,Me),p(e,ft,a),p(e,Ge,a),ht=!0},p:Bn,i(e){ht||(g(U.$$.fragment,e),g(Z.$$.fragment,e),g(Q.$$.fragment,e),g(ee.$$.fragment,e),g(te.$$.fragment,e),g(ne.$$.fragment,e),g(oe.$$.fragment,e),g(re.$$.fragment,e),g(ie.$$.fragment,e),g(se.$$.fragment,e),g(ae.$$.fragment,e),g(pe.$$.fragment,e),g(le.$$.fragment,e),g(me.$$.fragment,e),g(ue.$$.fragment,e),g(de.$$.fragment,e),g(ce.$$.fragment,e),g(fe.$$.fragment,e),g(he.$$.fragment,e),ht=!0)},o(e){x(U.$$.fragment,e),x(Z.$$.fragment,e),x(Q.$$.fragment,e),x(ee.$$.fragment,e),x(te.$$.fragment,e),x(ne.$$.fragment,e),x(oe.$$.fragment,e),x(re.$$.fragment,e),x(ie.$$.fragment,e),x(se.$$.fragment,e),x(ae.$$.fragment,e),x(pe.$$.fragment,e),x(le.$$.fragment,e),x(me.$$.fragment,e),x(ue.$$.fragment,e),x(de.$$.fragment,e),x(ce.$$.fragment,e),x(fe.$$.fragment,e),x(he.$$.fragment,e),ht=!1},d(e){e&&(t(je),t(Fe),t(Ke),t(O),t(Je),t(G),t(Ye),t(j),t(Ze),t(K),t(Qe),t(J),t(et),t(Y),t(tt),t(w),t(nt),t(d),t(ot),t(b),t(rt),t(C),t(it),t(T),t(st),t(N),t(at),t(P),t(pt),t(k),t(lt),t(E),t(mt),t(A),t(ut),t(S),t(dt),t(D),t(ct),t(L),t(ft),t(Ge)),t($),v(U),v(Z),v(Q),v(ee),v(te),v(ne),v(oe),v(re),v(ie),v(se),v(ae),v(pe),v(le),v(me),v(ue),v(de),v(ce),v(fe),v(he)}}}const Yn={local:"configuration-classes-for-onnx-exports",sections:[{local:"optimum.exporters.onnx.OnnxConfig",title:"Base classes"},{local:"middleend-classes",sections:[{local:"optimum.exporters.onnx.TextEncoderOnnxConfig",title:"Text"},{local:"optimum.exporters.onnx.config.VisionOnnxConfig",title:"Vision"},{local:"optimum.exporters.onnx.config.TextAndVisionOnnxConfig",title:"Multi-modal"}],title:"Middle-end classes"}],title:"Configuration classes for ONNX exports"};function Zn(rn){return Un(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class oo extends Gn{constructor($){super(),jn(this,$,Zn,Jn,Wn,{})}}export{oo as component};
